package com.usky.park.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.usky.common.core.bean.CommonPage;
import com.usky.park.domain.EventEg;
import com.usky.park.mapper.EventEgMapper;
import com.usky.park.service.EventEgService;
import com.usky.common.mybatis.core.AbstractCrudService;
import com.usky.park.service.vo.EventEgStatisticVO;
import org.bouncycastle.util.StringList;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 门禁历史通行记录表 服务实现类
 * </p>
 *
 * @author zyj
 * @since 2023-03-31
 */
@Service
public class EventEgServiceImpl extends AbstractCrudService<EventEgMapper, EventEg> implements EventEgService {

    @Override
    public CommonPage<EventEg> eventEgList(String deviceName,String installAddress,String cardNo,String orgName,Integer eventType,Integer pageNum,Integer pageSize){
        IPage<EventEg> page = new Page<>(pageNum,pageSize);
        List<EventEg> list = new ArrayList<>();
        LambdaQueryWrapper<EventEg> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.like(StringUtils.isNotBlank(deviceName),EventEg::getDeviceName,deviceName)
                    .like(StringUtils.isNotBlank(installAddress),EventEg::getInstallAddress,installAddress)
                    .like(StringUtils.isNotBlank(cardNo),EventEg::getCardNo,cardNo)
                    .like(StringUtils.isNotBlank(orgName),EventEg::getOrgName,orgName)
                    .eq(eventType  != null,EventEg::getEventType,eventType)
                    .orderByDesc(EventEg::getId);
        page = this.page(page,queryWrapper);
        list = page.getRecords();

        return new CommonPage<>(list,page.getTotal(),pageNum,pageSize);

    }

    @Override
    public CommonPage<EventEg> eventEgOne(String deviceId,Integer pageNum,Integer pageSize){
        IPage<EventEg> page = new Page<>(pageNum,pageSize);
        LambdaQueryWrapper<EventEg> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(EventEg::getDeviceId,deviceId)
                .orderByDesc(EventEg::getId);
        page = this.page(page,queryWrapper);

        return new CommonPage<>(page.getRecords(),page.getTotal(),pageNum,pageSize);
    }

    @Override
    public List<EventEgStatisticVO> eventEgStatistic(List<String> enterDeviceId, List<String> outDeviceId, String startDate, String endDate){
        List<EventEgStatisticVO> list = new ArrayList<>();
        EventEgStatisticVO eventEgStatisticVO = new EventEgStatisticVO();
        eventEgStatisticVO.setEnterNum(numStatistic(enterDeviceId,startDate,endDate,1));
        eventEgStatisticVO.setOutNum(numStatistic(outDeviceId,startDate,endDate,0));
        list.add(eventEgStatisticVO);

        return list;
    }

    public Integer numStatistic(List<String> deviceId,String startDate,String endDate,Integer iType){
        Integer num = 0;
        LambdaQueryWrapper<EventEg> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.in(EventEg::getDeviceId,deviceId)
                .between(EventEg::getEventTime,startDate,endDate)
                .eq(EventEg::getInOutType,iType);
        num = this.count(queryWrapper);

        return num;
    }

}
